@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild::Repository::HTTP;
 use strict;
 use warnings;
 
-our $VERSION = '0.023_01';
+our $VERSION = '0.024_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -50,8 +50,7 @@ sub get_file {
   my $from = $self->location;
 
   my $uri = $self->build_uri($protocol, $host, $from, $file);
-  # if it is an absolute URI, then use the filename from the URI
-  $file = ($uri->path_segments())[-1] if $file =~ /^(?:https?|file):/;
+  $file = ($uri->path_segments())[-1];
   my $res = $self->connection->mirror($uri, $file);
   my ( $is_error, $content, $headers ) = $self->check_http_response( $res );
   croak "Download failed: " . $content if $is_error;
@@ -129,26 +128,20 @@ sub find_links_textbalanced {
 
 sub build_uri {
   my $self = shift;
-  my ($protocol, $host, $path, $file) = @_;
+  my ($protocol, $host, $path, $target) = @_;
 
-  $protocol ||= 'http'; # if no protocol is passed, default to HTTP
-  my $uri = URI->new($file);
-  return $uri if $uri->scheme; # if an absolute URI
-
-  unless ( $host =~ m'^(?:https?|file)://' ) {
-    $host = "$protocol://$host";
+  my $uri;
+  if (defined $host) {
+    my $base = URI->new($host);
+    unless (defined $base->scheme) {
+      $base = URI->new(($protocol || 'http') ."://$host");
+    }
+    $base->path($path) if defined $path;
+    $uri = URI->new_abs($target, $base);
+  }
+  else {
+    $uri = URI->new($target);
   }
-  $uri = URI->new( $host );
-  return $uri unless defined $path;
-
-  $path =~ s'/$'';
-  $uri->path( $path );
-  return $uri->canonical unless defined $file;
-
-  my @segments = $uri->path_segments;
-  shift @segments;
-  $uri->path_segments( @segments, $file );
-
   return $uri->canonical;
 }
 
